@@ -126,10 +126,13 @@ pdf::Environment::Environment(const char *argv0)
 
 void pdf::Environment::set_antialias(bool value)
 {
+  this->antialias = value;
+#if POPPLER_VERSION < 3100
   if (!globalParams->setAntialias(const_cast<char*>(value ? "yes" : "no")))
     throw UnableToSetParameter(_("Unable to set antialias parameter"));
   if (!globalParams->setVectorAntialias(const_cast<char*>(value ? "yes" : "no")))
     throw UnableToSetParameter(_("Unable to set vector antialias parameter"));
+#endif
 }
 
 
@@ -454,6 +457,17 @@ void pdf::set_color(splash::Color &result, uint8_t r, uint8_t g, uint8_t b)
  * ===============================================
  */
 
+bool pdf::Environment::antialias = false;
+
+pdf::Renderer::Renderer(pdf::splash::Color &paper_color, bool monochrome)
+: pdf::splash::OutputDevice(monochrome ? splashModeMono1 : splashModeRGB8, 4, false, paper_color)
+{
+#if POPPLER_VERSION >= 3100
+      this->setFontAntialias(pdf::Environment::antialias);
+      this->setVectorAntialias(pdf::Environment::antialias);
+#endif
+}
+
 void pdf::Renderer::drawLink(pdf::link::Link *link, pdf::Catalog *catalog)
 {
   std::string border_color;
